aboutsummaryrefslogtreecommitdiff
path: root/gcc/lra.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/lra.c')
-rw-r--r--gcc/lra.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/lra.c b/gcc/lra.c
index ed1f062..1230b25 100644
--- a/gcc/lra.c
+++ b/gcc/lra.c
@@ -2267,13 +2267,13 @@ bitmap_head lra_inheritance_pseudos;
/* Split regnos before the new spill pass. */
bitmap_head lra_split_regs;
-/* Reload pseudo regnos before the new assignmnet pass which still can
- be spilled after the assinment pass as memory is also accepted in
+/* Reload pseudo regnos before the new assignment pass which still can
+ be spilled after the assignment pass as memory is also accepted in
insns for the reload pseudos. */
bitmap_head lra_optional_reload_pseudos;
/* Pseudo regnos used for subreg reloads before the new assignment
- pass. Such pseudos still can be spilled after the assinment
+ pass. Such pseudos still can be spilled after the assignment
pass. */
bitmap_head lra_subreg_reload_pseudos;